@@ -275,11 +275,11 @@ class Char(ews_char, UserInteraction, Dialogs):
         super(Char, self).__init__(template=template, *args, **kwds)
         self.battle_diff_treshold = 4 #: The treshold of the char below which no hit is scored. 
     
-    def say(self, data, *args, **kwds): 
+    def say(self, data, autoscroll=True, *args, **kwds): 
         """Say something -> Show that the char says it."""
         data = _(data)
         for i in data.split("\n"): 
-            self.split_diag(i, localize=False, line_beginning = self.name + ': ', *args, **kwds)
+            self.split_diag(i, localize=False, autoscroll=autoscroll, line_beginning = self.name + ': ', *args, **kwds)
     
     def ask(self, data, localize=False, *args, **kwds): 
         """Say something -> Show that the char says it."""
