@@ -10,18 +10,14 @@ Usage:
     Start the internal test story of the textrpg. 
 
 Plans: 
-    - put all functions which need diag or ask or similar into a class, 
-      so diag and ask can be overridden by other modules (doesnt work right now). 
     - Simple to use functions in easy to read scriptfiles in the style of the ministory file. 
     - char.compete(other, skill_name) -> See who wins and by how much. 
     - a basic implementation as minimal api reference for anyrpg plugins.
-    - Show the text letter by letter, if that's possible. 
     - Add the basic scripting function "python_interpreter(startup_data)", which shows an interactive python interpreter with the startup data already entered and interpreted. 
 
 
 Ideas: 
     - Lazy loading modules, to be able to print stuff at once without having to print before the imports.
-    - Add getting experience for groups and show the chars together (only one experience header instead of one per char). 
 
 
 Basic design principles for the scripting language: 
@@ -47,10 +43,7 @@ Basic design principles for the scripting language:
     - In the story function, an action is a parameter of the story. 
        -> story(switch_background_image="bg_image.png")
 
-The code for the TextRPG can be found at U{http://dreehg.org/ArneBab/textrpg}
-
-Shell escape codes: 
-    - print 'abc';print '\033[2A';sleep(0.3);print 'abcd'; -> die geschriebene Zeile ersetzen. 
+The code for the TextRPG can be found at U{http://freehg.org/ArneBab/textrpg}
 
 """
 
@@ -59,7 +52,7 @@ try:
 except: 
     from rpg_lib.anyrpg import __copyright__, __url__, __author__
 
-__version__   = '0.4.6' 
+__version__   = '0.4.8' 
 # __date__      = '7th March 2007' 
 
 
